@@ -2,12 +2,13 @@ package Net::Dropbear::SSHd;
 
 use strict;
 use v5.8;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Child;
 
 use autodie;
 use Carp;
+use Try::Tiny;
 use Moo;
 use Types::Standard qw/ArrayRef HashRef GlobRef Str Int Bool InstanceOf/;
 
@@ -122,7 +123,7 @@ sub wait
   my $self = shift;
   if ($self->is_running)
   {
-    $self->child->wait;
+    try { $self->child->wait };
   }
 }
 
@@ -510,7 +511,7 @@ Jon Gentle E<lt>atrodo@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2015- Jon Gentle
+Copyright 2015-2016 Jon Gentle
 
 =head1 LICENSE
 
